==> lincks-2.1.tar.gz: lincks-2.1/libs/liblincks/logws.c <==
/* 
 * Linkoping Intelligent Communication of Knowledge System (LINCKS)
 *      Copyright (C) 1993, Lin Padgham, Ralph Rnnquist
 *       Department of Computer and Information Sciences
 *		University of Linkoping, Sweden
 *		    581 83 Linkoping, Sweden
 *		       lincks@ida.liu.se
 *
 * These collective LINCKS programs are free software; you can 
 * redistribute them and/or modify them under the terms of the GNU
 * General Public License as published by the Free Software Foundation,
 * version 2 of the License.
 *
 * These programs are distributed in the hope that they will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the programs; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* 
 * MODULE NAME: 	logws.c
 *
 * SCCSINFO:		@(#)logws.c	1.1 9/27/93
 *
 * ORIGINAL AUTHOR(S):  Mikael Ohlsson, Feb 1991
 *
 * MODIFICATIONS:
 *	<list mods with name and date>
 *
 * DESCRIPTION:
 *   This file contains LogMess called to log workspace errors on file
 *
 *********************************************************************
 * EXTERNALLY-CALLABLE ROUTINES FOUND IN THIS MODULE:
 *********************************************************************
 * void LogMess(va_alist)
 */

/*********************************************************************
 * INCLUDES:
 *********************************************************************/
#include <stdio.h>
#include <time.h>
#include <string.h>
#include <varargs.h>
#include "xconfig.h"
#include "lincks.h"
#include "systypes.h"

/*********************************************************************
 * EXTERNALLY-AVAILABLE	DATA FOUND IN THIS MODULE:
 *********************************************************************/
/* none */

/*********************************************************************
 * EXTERNAL FUNCTIONS USED BY THIS MODULE:
 *********************************************************************/
/* libshared.a */
extern void LogFile( /* va_alist */ );

#ifdef sun
extern time_t time();
#endif
/*********************************************************************
 * EXTERNAL DATA STRUCTURES USED BY THIS MODULE:
 *********************************************************************/
/* none */

/*********************************************************************
 * LOCAL DEFINES, STRUCTS, TYPEDEFS, ETC.:
 *********************************************************************/
/* none */

/*********************************************************************
 * INTERNAL FUNCTIONS USED BY THIS MODULE:
 *********************************************************************/
/* none */

/*********************************************************************
 * INTERNAL (STATIC) DATA: 
 *********************************************************************/
/* none */

/*  */
/**********************************************************************
 * Function: void LogMess(va_alist)
 * 
 * Logs an error message on file
 * 
 * Modifications:
 *      <list mods with name and date>
 */
#ifdef lint
/*VARARGS2*//*ARGSUSED*/
void LogMess(uid_, format_, va_alist)
    UID uid_;
    char *format_;
#else
void LogMess(va_alist)
#endif
    va_dcl
{
    va_list ap;
    int uid;		/* Assuming sizeof(UID) <= sizeof(int) */
    char *format;

    long secs;
    struct tm *t, *localtime();
    char msg[256];
    char userid[8];

    /* Get arguments */
    va_start(ap);
    uid = va_arg(ap, int);
    format = va_arg(ap, char *);

    if (format == NULL)
	format = "(null)";

    /* Build message */
    (void)vsprintf(msg, format, ap);
    switch (uid) {
    case UNKNOWN:
	(void)strcpy(userid, "U");
	break;
    case SUPERUSER:
	(void)strcpy(userid, "S");
	break;
    default:
	(void)sprintf(userid, "%d", uid);
    }

    /* Get current time */
    (void)time(&secs);
    t = localtime(&secs);
	
    /* Print time followed by error message on file */
    LogFile(WSLOG, "%02d-%02d-%02d  %02d:%02d:%02d  User: (%s) %d  DB: %s\n                    %s\n\n",
		        t->tm_year, t->tm_mon+1, t->tm_mday,
			t->tm_hour, t->tm_min, t->tm_sec,
	   	        userid, TCPIPNO, DBDIR, msg);
    va_end(ap);
}

==> lincks-2.2.1.tar.gz: lincks-2.2.1/libs/liblincks/logws.c <==
/* 
 * Linkoping Intelligent Communication of Knowledge System (LINCKS)
 *      Copyright (C) 1993, 1994 Lin Padgham, Ralph Rnnquist
 *       Department of Computer and Information Sciences
 *		University of Linkoping, Sweden
 *		    581 83 Linkoping, Sweden
 *		       lincks@ida.liu.se
 *
 * These collective LINCKS programs are free software; you can 
 * redistribute them and/or modify them under the terms of the GNU
 * General Public License as published by the Free Software Foundation,
 * version 2 of the License.
 *
 * These programs are distributed in the hope that they will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the programs; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* 
 * MODULE NAME: 	logws.c
 *
 * SCCSINFO:		@(#)logws.c	1.6 5/3/94
 *
 * ORIGINAL AUTHOR(S):  Mikael Ohlsson, Feb 1991
 *
 * MODIFICATIONS:
 *	<list mods with name and date>
 *
 * DESCRIPTION:
 *   This file contains LogMess called to log workspace errors on file
 *
 *********************************************************************
 * EXTERNALLY-CALLABLE ROUTINES FOUND IN THIS MODULE:
 *********************************************************************
 * void LogMess(va_alist)
 */

/*********************************************************************
 * INCLUDES:
 *********************************************************************/
#include "config.h"	/* includes system dependent includes */

#include <time.h>
#if defined(__STDC__)
#include <stdarg.h>
#else
#include <varargs.h>
#endif
#include "xconfig.h"
#include "lincks.h"

/*********************************************************************
 * EXTERNALLY-AVAILABLE	DATA FOUND IN THIS MODULE:
 *********************************************************************/
#include "f_logws.h"

/*********************************************************************
 * EXTERNAL FUNCTIONS USED BY THIS MODULE:
 *********************************************************************/
#include "f_logging.h"

#if defined(sun) || defined(__sun__)
extern time_t time P_((time_t *tloc));
#endif
/*********************************************************************
 * EXTERNAL DATA STRUCTURES USED BY THIS MODULE:
 *********************************************************************/
/* none */

/*********************************************************************
 * LOCAL DEFINES, STRUCTS, TYPEDEFS, ETC.:
 *********************************************************************/
/* none */

/*********************************************************************
 * INTERNAL FUNCTIONS USED BY THIS MODULE:
 *********************************************************************/
/* none */

/*********************************************************************
 * INTERNAL (STATIC) DATA: 
 *********************************************************************/
/* none */

/*  */
/**********************************************************************
 * Function: void LogMess(va_alist)
 * 
 * Logs an error message on file
 * 
 * Modifications:
 *      <list mods with name and date>
 */
#ifdef lint
/*VARARGS2*//*ARGSUSED*/
void LogMess(uid_, format_, va_alist)
    UID uid_;
    char *format_;
    va_dcl
#else
#ifdef __STDC__
void LogMess(int uid, char *format, ... )
#else
void LogMess(va_alist)
    va_dcl
#endif
#endif
{
    va_list ap;
#ifndef __STDC__
    int uid;		/* Assuming sizeof(UID) <= sizeof(int) */
    char *format;
#endif /* n __STDC__ */
    time_t secs;
    struct tm *t, *localtime();
    char msg[256];
    char userid[8];

    /* Get arguments */
#ifdef __STDC__
    va_start(ap, format);
#else
    va_start(ap);
    uid = va_arg(ap, int);
    format = va_arg(ap, char *);
#endif /* n __STDC__ */

    if (format == NULL)
	format = "(null)";

    /* Build message */
    (void)vsprintf(msg, format, ap);
    switch (uid) {
    case UNKNOWN:
	(void)strcpy(userid, "U");
	break;
    case SUPERUSER:
	(void)strcpy(userid, "S");
	break;
    default:
	(void)sprintf(userid, "%d", uid);
    }

    /* Get current time */
    (void)time(&secs);
    t = localtime(&secs);
	
    /* Print time followed by error message on file */
    LogFile(WSLOG, "%02d-%02d-%02d  %02d:%02d:%02d  User: (%s) %d  DB: %s\n                    %s\n\n",
		        t->tm_year, t->tm_mon+1, t->tm_mday,
			t->tm_hour, t->tm_min, t->tm_sec,
	   	        userid, TCPIPNO, DBDIR, msg);
    va_end(ap);
}
